@@ -12,8 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 from oslo_serialization import jsonutils
-from six.moves import http_client
 import webob.dec
 
 from murano.common import wsgi
@@ -45,7 +45,7 @@ class Controller(object):
         response = webob.Response(request=req,
                                   status=http_client.MULTIPLE_CHOICES,
                                   content_type='application/json')
-        response.text = jsonutils.dumps(dict(versions=version_objs))
+        response.body = jsonutils.dumps(dict(versions=version_objs))
         return response
 
     @webob.dec.wsgify(RequestClass=wsgi.Request)
