@@ -64,7 +64,7 @@ class EngineService(service.Service):
             SchemaEndpoint()
         ]
 
-        transport = messaging.get_notification_transport(CONF)
+        transport = messaging.get_rpc_transport(CONF)
         s_target = target.Target('murano', 'tasks', server=str(uuid.uuid4()))
         access_policy = dispatcher.DefaultRPCAccessPolicy
         self.server = messaging.get_rpc_server(
@@ -141,8 +141,9 @@ class TaskProcessingEndpoint(object):
             result = task_executor.execute()
             return result
         finally:
+            s_result = token_sanitizer.TokenSanitizer().sanitize(result)
             LOG.info('Finished processing task: {task_desc}'.format(
-                task_desc=jsonutils.dumps(result)))
+                task_desc=jsonutils.dumps(s_result)))
 
 
 class StaticActionEndpoint(object):
@@ -322,7 +323,7 @@ class TaskExecutor(object):
     def _delete_trust(self):
         trust_id = self._session.trust_id
         if trust_id:
-            auth_utils.delete_trust(self._session.trust_id)
+            auth_utils.delete_trust(self._session)
             self._session.system_attributes['TrustId'] = None
             self._session.trust_id = None
 
