@@ -12,9 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from murano.common import policy
 from oslo_context import context
 
+from murano.common import policy
+
 
 class RequestContext(context.RequestContext):
     """Class that stores context info about an API request.
@@ -23,18 +24,10 @@ class RequestContext(context.RequestContext):
     as well as additional request information.
     """
 
-    def __init__(self, session=None,
-                 roles=None, is_admin=None,
+    def __init__(self, session=None, service_catalog=None,
                  **kwargs):
         super(RequestContext, self).__init__(**kwargs)
         self.session = session
-        self.roles = roles or []
-
-        self.is_admin = is_admin
+        self.service_catalog = service_catalog
         if self.is_admin is None:
             self.is_admin = policy.check_is_admin(self)
-
-    def to_dict(self):
-        d = super(RequestContext, self).to_dict()
-        d.setdefault('roles', self.roles)
-        return d
