@@ -14,12 +14,12 @@
 # limitations under the License.
 
 import logging
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_utils import timeutils
 import routes
-from six.moves import urllib
+import urllib
 import webob
 
 from murano.api.v1 import request_statistics
