@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
 
 from keystoneauth1 import loading as ka_loading
 
@@ -48,8 +48,8 @@ class TestAuthUtils(base.MuranoTestCase):
         cfg.CONF.set_override('auth_type',
                               'password',
                               auth_utils.CFG_MURANO_AUTH_GROUP)
-        cfg.CONF.set_override('auth_uri',
-                              'foo_auth_uri',
+        cfg.CONF.set_override('www_authenticate_uri',
+                              'foo_www_authenticate_uri',
                               auth_utils.CFG_MURANO_AUTH_GROUP)
         cfg.CONF.set_override('auth_url',
                               'foo_auth_url',
@@ -158,8 +158,8 @@ class TestAuthUtils(base.MuranoTestCase):
     def test_get_token_client_session(
             self, mock_get_execution_session, mock_identity,
             mock_get_session):
-        cfg.CONF.set_override('auth_uri',
-                              'foo_auth_uri/v2.0',
+        cfg.CONF.set_override('www_authenticate_uri',
+                              'foo_www_authenticate_uri/v2.0',
                               auth_utils.CFG_MURANO_AUTH_GROUP)
 
         mock_get_execution_session.return_value = \
@@ -173,7 +173,7 @@ class TestAuthUtils(base.MuranoTestCase):
 
         mock_get_execution_session.assert_called_once_with()
         mock_identity.Token.assert_called_once_with(
-            'foo_auth_uri/v3', token=mock.sentinel.token,
+            'foo_www_authenticate_uri/v3', token=mock.sentinel.token,
             project_id=mock.sentinel.project_id)
         mock_get_session.assert_called_once_with(
             auth=mock.sentinel.auth,
@@ -238,16 +238,23 @@ class TestAuthUtils(base.MuranoTestCase):
             role_names=mock.sentinel.role_names,
             project=mock.sentinel.project_id)
 
-    @mock.patch.object(
-        auth_utils, '_create_keystone_admin_client', autospec=True)
-    def test_delete_trust(self, mock_create_ks_admin_client):
-        mock_admin_client = mock.Mock()
-        mock_create_ks_admin_client.return_value = mock_admin_client
+    @mock.patch.object(auth_utils, 'create_keystone_client', autospec=True)
+    def test_delete_trust(self, mock_ks_client):
+        mock_auth_ref = mock.Mock(trust_id=mock.sentinel.trust_id,
+                                  token=mock.sentinel.token,
+                                  project_id=mock.sentinel.project_id)
+        mock_user_session = mock.Mock(**{
+            'auth.get_access.return_value': mock_auth_ref
+        })
+        mock_user_client = mock.Mock(
+            session=mock_user_session)
 
-        auth_utils.delete_trust(mock.sentinel.trust)
+        mock_ks_client.return_value = mock_user_client
 
-        mock_admin_client.trusts.delete.assert_called_once_with(
-            mock.sentinel.trust)
+        auth_utils.delete_trust(mock_auth_ref)
+
+        mock_user_client.trusts.delete.assert_called_once_with(
+            mock_auth_ref.trust_id)
 
     def test_get_config_option(self):
         cfg.CONF.set_override('url', 'foourl', 'murano')
