@@ -18,8 +18,8 @@ from muranoclient.common import exceptions as muranoclient_exc
 import os
 import shutil
 import tempfile
+from unittest import mock
 
-import mock
 import semantic_version
 import testtools
 
@@ -28,7 +28,7 @@ from murano.dsl import murano_package as dsl_package
 from murano.engine import package_loader
 from murano.packages import exceptions as pkg_exc
 from murano.tests.unit import base
-from murano_tempest_tests import utils
+from murano.tests.unit import utils
 
 
 class TestPackageCache(base.MuranoTestCase):
@@ -200,6 +200,8 @@ class TestPackageCache(base.MuranoTestCase):
         package = mock.MagicMock()
         package.fully_qualified_name = fqn
         package.classes = ['test_class_1', 'test_class_2']
+        test_version = semantic_version.Version('1.1.0')
+        package.version = test_version
         self.loader.register_package(package)
 
         spec = semantic_version.Spec('*')
